@@ -2,5 +2,7 @@ export { BaseError } from './BaseError';
 export { Problem } from './Problem';
 export { ERROR_TYPE, type ErrorType } from './constants';
 export { isRecoverable, extractErrorFromFetchResponse } from './extractErrorFromFetchResponse';
+export { getLoginErrorMessage } from './getLoginErrorMessage';
+export { getResetPasswordErrorMessage } from './getResetPasswordErrorMessage';
 
 export * from './errors';
