@@ -292,6 +292,18 @@ export const practitioner = [
   { verb: 'create', noun: 'LocationSchedule' },
   { verb: 'write', noun: 'LocationSchedule' },
   { verb: 'delete', noun: 'LocationSchedule' },
+
+  { verb: 'read', noun: 'MedicationRequest' },
+  { verb: 'list', noun: 'MedicationRequest' },
+  { verb: 'create', noun: 'MedicationRequest' },
+  { verb: 'write', noun: 'MedicationRequest' },
+  { verb: 'delete', noun: 'MedicationRequest' },
+
+  { verb: 'read', noun: 'MedicationDispense' },
+  { verb: 'list', noun: 'MedicationDispense' },
+  { verb: 'create', noun: 'MedicationDispense' },
+  { verb: 'write', noun: 'MedicationDispense' },
+  { verb: 'delete', noun: 'MedicationDispense' },
 ];
 
 // "Manage all" is a special case in CASL for the admin to grant everything
